from odoo.addons.sale.tests.common import TestSaleCommon
from odoo import Command

class TestCommonSalePurchaseNoChart(TestSaleCommon):

    @classmethod
    def setUpClass(cls, chart_template_ref=None):
        super().setUpClass(chart_template_ref=chart_template_ref)

        uom_unit = cls.env.ref('uom.product_uom_unit')
        uom_dozen = cls.env.ref('uom.product_uom_dozen')

        # Create category
        cls.product_category_purchase = cls.env['product.category'].create({
            'name': 'Product Category with Income account',
            'property_account_income_categ_id': cls.company_data['default_account_expense'].id
        })

        cls.partner_vendor_serviceA = cls.env['res.partner'].create({
            'name': 'Service Supplier AAA',
            'email': 'supplierA@example.com',
        })

        cls.partner_vendor_serviceBCcpy = cls.env['res.partner'].create({
            'name': 'Service Supplier BBB Ltd',
            'email': 'supplierBcpy@example.com',
            'is_company': True,
        })

        cls.partner_vendor_serviceBC = cls.env['res.partner'].create({
            'name': 'Service Supplier BBB',
            'email': 'supplierB@example.com',
            'parent_id': cls.partner_vendor_serviceBCcpy.id,
            'is_company': False,
        })

        cls.supplierinfo1 = cls.env['product.supplierinfo'].create({
            'partner_id': cls.partner_vendor_serviceA.id,
            'price': 70,
            'delay': 0,
        })
        cls.supplierinfo2 = cls.env['product.supplierinfo'].create({
            'partner_id': cls.partner_vendor_serviceBC.id,
            'price': 7,
            'delay': 0,
        })
        cls.supplierinfo3 = cls.env['product.supplierinfo'].create({
            'partner_id': cls.partner_vendor_serviceBC.id,
            'price': 35,
            'delay': 0,
        })

        # Create product
        cls.service_purchase_1 = cls.env['product.product'].create({
            'name': "APPS AAA",
            'standard_price': 100.0,
            'list_price': 100.0,
            'type': 'service',
            'uom_id': uom_unit.id,
            'uom_po_id': uom_unit.id,
            'invoice_policy': 'order',
            'expense_policy': 'no',
            'default_code': 'APP_A',
            'service_type': 'manual',
            'taxes_id': False,
            'service_to_purchase': True,
            'seller_ids': [Command.set(cls.supplierinfo1.ids)],
        })
        cls.service_purchase_2 = cls.env['product.product'].create({
            'name': "APPS BBB",
            'standard_price': 10.0,
            'list_price': 10.0,
            'type': 'service',
            'uom_id': uom_dozen.id,
            'uom_po_id': uom_unit.id,
            'invoice_policy': 'order',
            'expense_policy': 'no',
            'default_code': 'APP_B',
            'service_type': 'manual',
            'taxes_id': False,
            'service_to_purchase': True,
            'seller_ids': [Command.set(cls.supplierinfo2.ids)],
        })

        cls.service_purchase_3 = cls.env['product.product'].create({
            'name': "APPS CCC",
            'standard_price': 50.0,
            'list_price': 50.0,
            'type': 'service',
            'uom_id': uom_dozen.id,
            'uom_po_id': uom_unit.id,
            'invoice_policy': 'order',
            'expense_policy': 'no',
            'default_code': 'APP_B',
            'service_type': 'manual',
            'taxes_id': False,
            'service_to_purchase': True,
            'seller_ids': [Command.set(cls.supplierinfo2.ids)],
        })

        cls.supplierinfo1.product_tmpl_id = cls.service_purchase_1.product_tmpl_id.id
        cls.supplierinfo2.product_tmpl_id = cls.service_purchase_2.product_tmpl_id.id
        cls.supplierinfo3.product_tmpl_id = cls.service_purchase_3.product_tmpl_id.id
